@@ -41,9 +41,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         super().to_dict()
         if not self.yaml_file:
             spec = self.res.setdefault("spec", {})
-            spec.setdefault("source", {})[
-                "apiGroup"
-            ] = NamespacedResource.ApiGroup.KUBEVIRT_IO
+            spec.setdefault("source", {})["apiGroup"] = NamespacedResource.ApiGroup.KUBEVIRT_IO
             spec["source"]["kind"] = VirtualMachine.kind
             spec["source"]["name"] = self.vm_name
 
@@ -58,10 +56,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         Raises:
             TimeoutExpiredError: If timeout reached.
         """
-        self.logger.info(
-            f"Wait for {self.kind} {self.name} status to be"
-            f" {'' if status else 'not '}ready to use"
-        )
+        self.logger.info(f"Wait for {self.kind} {self.name} status to be {'' if status else 'not '}ready to use")
 
         timeout_watcher = TimeoutWatch(timeout=timeout)
         for sample in TimeoutSampler(
